django_turnit.management package
================================

.. automodule:: django_turnit.management
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    django_turnit.management.commands

